@@ -4,6 +4,7 @@ from typing import Optional
 import annoworkcli
 import annoworkcli.actual_working_time.delete_actual_working_time
 import annoworkcli.actual_working_time.list_actual_working_hours_daily
+import annoworkcli.actual_working_time.list_actual_working_hours_daily_groupby_tag
 import annoworkcli.actual_working_time.list_actual_working_time
 
 
@@ -16,6 +17,7 @@ def parse_args(parser: argparse.ArgumentParser):
     # annoworkcli.actual_working_time.delete_actual_working_time.add_parser(subparsers)
     annoworkcli.actual_working_time.list_actual_working_time.add_parser(subparsers)
     annoworkcli.actual_working_time.list_actual_working_hours_daily.add_parser(subparsers)
+    annoworkcli.actual_working_time.list_actual_working_hours_daily_groupby_tag.add_parser(subparsers)
 
 
 def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
