@@ -19,55 +19,51 @@ logger = logging.getLogger(__name__)
 
 
 class ListAssignedHoursDailyGroupbyTag:
-    def __init__(self, annowork_service: AnnoworkResource, organization_id: str):
+    def __init__(self, annowork_service: AnnoworkResource, workspace_id: str):
         self.annowork_service = annowork_service
-        self.organization_id = organization_id
-        self.list_schedule_obj = ListSchedule(annowork_service, organization_id)
+        self.workspace_id = workspace_id
+        self.list_schedule_obj = ListSchedule(annowork_service, workspace_id)
 
     def get_assigned_hours_groupby_tag(
         self,
         assigned_hours_list: list[AssignedHoursDaily],
-        target_organization_tag_ids: Optional[Collection[str]] = None,
-        target_organization_tag_names: Optional[Collection[str]] = None,
+        target_workspace_tag_ids: Optional[Collection[str]] = None,
+        target_workspace_tag_names: Optional[Collection[str]] = None,
     ) -> list[dict[str, Any]]:
-        """アサイン時間のlistから、組織タグごとに集計したlistを返す。"""
-        organization_tags = self.annowork_service.api.get_organization_tags(self.organization_id)
+        """アサイン時間のlistから、ワークスペースタグごとに集計したlistを返す。"""
+        workspace_tags = self.annowork_service.api.get_workspace_tags(self.workspace_id)
 
-        # target_organization_tag_idsとtarget_organization_tag_namesは排他的なので、両方not Noneになることはない
-        assert not (target_organization_tag_ids is not None and target_organization_tag_names is not None)
-        if target_organization_tag_ids is not None:
-            organization_tags = [
-                e for e in organization_tags if e["organization_tag_id"] in set(target_organization_tag_ids)
-            ]
-            if len(organization_tags) != len(target_organization_tag_ids):
+        # target_workspace_tag_idsとtarget_workspace_tag_namesは排他的なので、両方not Noneになることはない
+        assert not (target_workspace_tag_ids is not None and target_workspace_tag_names is not None)
+        if target_workspace_tag_ids is not None:
+            workspace_tags = [e for e in workspace_tags if e["workspace_tag_id"] in set(target_workspace_tag_ids)]
+            if len(workspace_tags) != len(target_workspace_tag_ids):
                 logger.warning(
-                    f"target_organization_tag_idsに含まれるいくつかのorganization_tag_idは、存在しません。"
-                    f":: {len(target_organization_tag_ids)=}, {len(organization_tags)=}"
+                    f"target_workspace_tag_idsに含まれるいくつかのworkspace_tag_idは、存在しません。"
+                    f":: {len(target_workspace_tag_ids)=}, {len(workspace_tags)=}"
                 )
 
-        if target_organization_tag_names is not None:
-            organization_tags = [
-                e for e in organization_tags if e["organization_tag_name"] in set(target_organization_tag_names)
-            ]
-            if len(organization_tags) != len(target_organization_tag_names):
+        if target_workspace_tag_names is not None:
+            workspace_tags = [e for e in workspace_tags if e["workspace_tag_name"] in set(target_workspace_tag_names)]
+            if len(workspace_tags) != len(target_workspace_tag_names):
                 logger.warning(
-                    "target_organization_tag_namesに含まれるいくつかのorganization_tag_nameは、存在しません。"
-                    f":: {len(target_organization_tag_names)=}, {len(organization_tags)=}"
+                    "target_workspace_tag_namesに含まれるいくつかのworkspace_tag_nameは、存在しません。"
+                    f":: {len(target_workspace_tag_names)=}, {len(workspace_tags)=}"
                 )
 
-        # dictのkeyはtuple[date, job_id, organization_tag_name]
+        # dictのkeyはtuple[date, job_id, workspace_tag_name]
         dict_hours: dict[tuple[str, str, str], float] = defaultdict(float)
 
-        # 組織タグごと日毎の時間を集計する
-        for organization_tag in organization_tags:
-            organization_tag_name = organization_tag["organization_tag_name"]
-            members = self.annowork_service.api.get_organization_tag_members(
-                self.organization_id, organization_tag["organization_tag_id"]
+        # ワークスペースタグごと日毎の時間を集計する
+        for workspace_tag in workspace_tags:
+            workspace_tag_name = workspace_tag["workspace_tag_name"]
+            members = self.annowork_service.api.get_workspace_tag_members(
+                self.workspace_id, workspace_tag["workspace_tag_id"]
             )
-            member_ids = {e["organization_member_id"] for e in members}
+            member_ids = {e["workspace_member_id"] for e in members}
             for elm in assigned_hours_list:
-                if elm.organization_member_id in member_ids:
-                    dict_hours[elm.date, elm.job_id, organization_tag_name] += elm.assigned_working_hours
+                if elm.workspace_member_id in member_ids:
+                    dict_hours[elm.date, elm.job_id, workspace_tag_name] += elm.assigned_working_hours
 
         # 全体の時間を日毎に集計する
 
@@ -99,10 +95,10 @@ class ListAssignedHoursDailyGroupbyTag:
         end_date: Optional[str],
         job_id_list: Optional[list[str]],
         user_id_list: Optional[list[str]],
-        target_organization_tag_ids: Optional[Collection[str]],
-        target_organization_tag_names: Optional[Collection[str]],
+        target_workspace_tag_ids: Optional[Collection[str]],
+        target_workspace_tag_names: Optional[Collection[str]],
     ):
-        list_obj = ListAssignedHoursDaily(self.annowork_service, self.organization_id)
+        list_obj = ListAssignedHoursDaily(self.annowork_service, self.workspace_id)
         assigned_hours_list = list_obj.get_assigned_hours_daily_list(
             start_date=start_date,
             end_date=end_date,
@@ -115,8 +111,8 @@ class ListAssignedHoursDailyGroupbyTag:
 
         results = self.get_assigned_hours_groupby_tag(
             assigned_hours_list,
-            target_organization_tag_ids=target_organization_tag_ids,
-            target_organization_tag_names=target_organization_tag_names,
+            target_workspace_tag_ids=target_workspace_tag_ids,
+            target_workspace_tag_names=target_workspace_tag_names,
         )
         logger.info(f"{len(results)} 件のアサイン時間情報を出力します。")
 
@@ -150,28 +146,28 @@ def main(args):
             "'--start_date'や'--job_id'などの絞り込み条件が1つも指定されていません。" "WebAPIから取得するデータ量が多すぎて、WebAPIのリクエストが失敗するかもしれません。"
         )
 
-    organization_tag_id_list = get_list_from_args(args.organization_tag_id)
-    organization_tag_name_list = get_list_from_args(args.organization_tag_name)
+    workspace_tag_id_list = get_list_from_args(args.workspace_tag_id)
+    workspace_tag_name_list = get_list_from_args(args.workspace_tag_name)
 
-    ListAssignedHoursDailyGroupbyTag(annowork_service=annowork_service, organization_id=args.organization_id,).main(
+    ListAssignedHoursDailyGroupbyTag(annowork_service=annowork_service, workspace_id=args.workspace_id,).main(
         job_id_list=job_id_list,
         user_id_list=user_id_list,
         start_date=start_date,
         end_date=end_date,
         output=args.output,
         output_format=OutputFormat(args.format),
-        target_organization_tag_ids=organization_tag_id_list,
-        target_organization_tag_names=organization_tag_name_list,
+        target_workspace_tag_ids=workspace_tag_id_list,
+        target_workspace_tag_names=workspace_tag_name_list,
     )
 
 
 def parse_args(parser: argparse.ArgumentParser):
     parser.add_argument(
-        "-org",
-        "--organization_id",
+        "-w",
+        "--workspace_id",
         type=str,
         required=True,
-        help="対象の組織ID",
+        help="対象のワークスペースID",
     )
 
     parser.add_argument("-u", "--user_id", type=str, nargs="+", required=False, help="絞り込み対象のユーザID")
@@ -183,18 +179,18 @@ def parse_args(parser: argparse.ArgumentParser):
 
     org_tag_group = parser.add_mutually_exclusive_group()
     org_tag_group.add_argument(
-        "-org_tag",
-        "--organization_tag_id",
+        "-wt",
+        "--workspace_tag_id",
         type=str,
         nargs="+",
-        help="出力対象の組織タグID。未指定の場合は全ての組織タグを出力します。",
+        help="出力対象のワークスペースタグID。未指定の場合は全てのワークスペースタグを出力します。",
     )
 
     org_tag_group.add_argument(
-        "--organization_tag_name",
+        "--workspace_tag_name",
         type=str,
         nargs="+",
-        help="出力対象の組織タグ名。未指定の場合は全ての組織タグを出力します。",
+        help="出力対象のワークスペースタグ名。未指定の場合は全てのワークスペースタグを出力します。",
     )
 
     parser.add_argument("-o", "--output", type=Path, help="出力先")
@@ -213,7 +209,7 @@ def parse_args(parser: argparse.ArgumentParser):
 
 def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
     subcommand_name = "list_daily_groupby_tag"
-    subcommand_help = "日ごとのアサイン時間を、組織タグで集計した値を出力します。"
+    subcommand_help = "日ごとのアサイン時間を、ワークスペースタグで集計した値を出力します。"
 
     parser = annoworkcli.common.cli.add_parser(
         subparsers, subcommand_name, subcommand_help, description=subcommand_help
